# server.py - IACC 2.0 智能代理协作控制器
import os
import json
import re
from pathlib import Path
from typing import Dict, List, Any, Optional, Tuple
from dataclasses import dataclass
from enum import Enum
try:
    from fastmcp import FastMCP
except ImportError:
    try:
        from mcp.server.fastmcp import FastMCP
    except ImportError:
        # 如果fastmcp不可用，创建一个Mock类
        class FastMCP:
            def __init__(self, name, description=""):
                self.name = name
                self.description = description
                self.tools = []
                self.resources = []
            
            def tool(self):
                def decorator(func):
                    self.tools.append(func)
                    return func
                return decorator
            
            def resource(self, uri):
                def decorator(func):
                    self.resources.append(func)
                    return func
                return decorator
            
            def run(self, transport="stdio"):
                print(f"Mock MCP Server '{self.name}' started")
        
        print("⚠️  FastMCP不可用，使用Mock实现")

# Create an MCP server
mcp = FastMCP("IACC-2.0-Controller", description="智能代理协作控制器 - 4层精简架构")

class LayerType(Enum):
    """4层架构类型定义"""
    L1_PRODUCT = "L1: 产品需求分析层"
    L2_ARCHITECT = "L2: 技术架构设计层"
    L3_IMPLEMENTATION = "L3: 代码实现层"
    L4_QUALITY = "L4: 质量保证层"

class ExpertType(Enum):
    """专家类型定义"""
    # 后端开发
    JAVA_BACKEND = "Java后台开发专家"
    GO_BLOCKCHAIN = "Go区块链开发工程师"
    
    # 前端开发
    REACT_FRONTEND = "React开发专家"
    VUE_FRONTEND = "Vue开发专家"
    
    # 移动开发
    ANDROID_MOBILE = "Android开发专家"
    ANDROID_FFMPEG = "Android FFmpeg专家"
    ANDROID_IJKPLAYER = "Android IJKPlayer专家"
    ANDROID_WEBRTC = "Android WebRTC专家"
    
    # Web3区块链
    WEB3_BLOCKCHAIN = "Web3区块链专家"
    WEB3_GO = "Web3 Go开发专家"
    SOLANA_DEV = "Solana开发专家"
    SOLIDITY_CONTRACT = "Solidity智能合约架构师"
    
    # 产品和运营
    PRODUCT_MANAGER = "高级产品思维专家"
    OPERATION_STRATEGY = "高级运营策略架构师"

@dataclass
class WorkflowState:
    """工作流状态管理"""
    request_id: str
    user_input: str
    complexity: int
    selected_experts: List[ExpertType]
    layer_outputs: Dict[LayerType, Dict]
    current_layer: Optional[LayerType] = None
    status: str = "initialized"

@dataclass
class ExpertRule:
    """专家规则定义"""
    name: str
    type: ExpertType
    skills: List[str]
    keywords: List[str]
    rules_content: str
    file_path: str

class ExpertSelector:
    """专家智能选择器"""
    
    def __init__(self):
        self.experts: Dict[str, ExpertRule] = {}
        self.rules_base_path = Path(".cursor/rules")
        self.load_expert_rules()
    
    def load_expert_rules(self):
        """加载专家规则库 - 自动扫描所有文件"""
        print(f"🔍 开始扫描专家规则目录: {self.rules_base_path}")
        
        if not self.rules_base_path.exists():
            print("⚠️  专家规则目录不存在，使用默认配置")
            self._load_default_experts()
            return
        
        # 扫描所有子目录中的.mdc和.md文件
        expert_count = 0
        for folder in self.rules_base_path.iterdir():
            if folder.is_dir():
                print(f"📁 扫描目录: {folder.name}")
                for file in folder.iterdir():
                    if file.suffix.lower() in ['.md', '.mdc']:
                        expert_name = self._generate_expert_name(file)
                        keywords = self._generate_keywords(file, folder.name)
                        
                        try:
                            with open(file, 'r', encoding='utf-8') as f:
                                content = f.read()
                            
                            expert_type = self._parse_expert_type(expert_name)
                            
                            self.experts[expert_name] = ExpertRule(
                                name=expert_name,
                                type=expert_type,
                                skills=self._extract_skills(content),
                                keywords=keywords,
                                rules_content=content,
                                file_path=str(file)
                            )
                            
                            expert_count += 1
                            print(f"✅ 加载专家: {expert_name} 从 {file.name}")
                            
                        except Exception as e:
                            print(f"❌ 加载失败 {file}: {e}")
        
        print(f"📊 专家加载完成，共加载 {expert_count} 个专家")
    
    def _generate_expert_name(self, file_path: Path) -> str:
        """根据文件名生成专家名称"""
        file_name = file_path.stem  # 去掉扩展名
        
        # 专家名称映射表
        name_mapping = {
            # Android专家
            "android-common": "Android开发专家",
            "android-ffmpeg": "Android FFmpeg专家",
            "android-ijkplayer": "Android IJKPlayer专家", 
            "android-webrtc": "Android WebRTC专家",
            
            # 后端专家
            "java-common": "Java后台开发专家",
            "go": "Go区块链开发工程师",
            
            # 前端专家
            "front-react": "React开发专家",
            "front-vue": "Vue开发专家",
            
            # 产品专家
            "product": "高级产品思维专家",
            "yunying": "高级运营策略架构师",
            
            # Web3专家
            "solana": "Solana开发专家",
            "solidity": "Solidity智能合约架构师",
            "web3-common": "Web3区块链专家",
            "web3-go": "Web3 Go开发专家"
        }
        
        return name_mapping.get(file_name, f"{file_name}开发专家")
    
    def _generate_keywords(self, file_path: Path, folder_name: str) -> List[str]:
        """根据文件名和文件夹生成关键词"""
        file_name = file_path.stem.lower()
        
        # 基础关键词
        folder_keywords = {
            "android": ["android", "移动", "app", "移动端"],
            "back": ["后端", "服务器", "api", "数据库"],
            "front": ["前端", "web", "ui", "界面"],
            "product": ["产品", "需求", "用户", "策略"],
            "web3": ["区块链", "web3", "智能合约", "defi"]
        }
        
        # 文件特定关键词
        file_keywords = {
            "java": ["java", "spring", "微服务"],
            "go": ["go", "golang", "并发"],
            "react": ["react", "jsx", "组件"],
            "vue": ["vue", "响应式", "双向绑定"],
            "android": ["kotlin", "jetpack"],
            "ffmpeg": ["ffmpeg", "音视频", "编码"],
            "ijkplayer": ["ijkplayer", "播放器", "视频"],
            "webrtc": ["webrtc", "实时通信", "音视频"],
            "solana": ["solana", "rust", "高性能"],
            "solidity": ["solidity", "以太坊", "智能合约"],
            "product": ["产品设计", "用户体验"],
            "yunying": ["运营", "增长", "数据分析"]
        }
        
        keywords = folder_keywords.get(folder_name, [])
        
        # 添加文件特定关键词
        for key, words in file_keywords.items():
            if key in file_name:
                keywords.extend(words)
        
        return list(set(keywords)) if keywords else ["通用"]
    
    def _load_expert_from_folder(self, expert_name: str, folder: str, keywords: List[str]):
        """从文件夹加载专家规则"""
        folder_path = self.rules_base_path / folder
        if folder_path.exists():
            # 尝试加载文件夹中的md或mdc文件
            for pattern in ["*.md", "*.mdc"]:
                for md_file in folder_path.glob(pattern):
                    try:
                        with open(md_file, 'r', encoding='utf-8') as f:
                            content = f.read()
                        
                        # 解析专家类型
                        expert_type = self._parse_expert_type(expert_name)
                        
                        self.experts[expert_name] = ExpertRule(
                            name=expert_name,
                            type=expert_type,
                            skills=self._extract_skills(content),
                            keywords=keywords,
                            rules_content=content,
                            file_path=str(md_file)
                        )
                        print(f"✅ 成功加载专家: {expert_name} 从 {md_file.name}")
                        return  # 找到一个文件就停止
                    except Exception as e:
                        print(f"❌ 加载专家规则失败 {md_file}: {e}")
            
            print(f"⚠️  未找到专家规则文件: {folder_path}")
        else:
            print(f"⚠️  专家规则目录不存在: {folder_path}")
    
    def _parse_expert_type(self, expert_name: str) -> ExpertType:
        """解析专家类型"""
        type_mapping = {
            # 后端开发
            "Java后台开发专家": ExpertType.JAVA_BACKEND,
            "Go区块链开发工程师": ExpertType.GO_BLOCKCHAIN,
            
            # 前端开发
            "React开发专家": ExpertType.REACT_FRONTEND,
            "Vue开发专家": ExpertType.VUE_FRONTEND,
            
            # 移动开发
            "Android开发专家": ExpertType.ANDROID_MOBILE,
            "Android FFmpeg专家": ExpertType.ANDROID_FFMPEG,
            "Android IJKPlayer专家": ExpertType.ANDROID_IJKPLAYER,
            "Android WebRTC专家": ExpertType.ANDROID_WEBRTC,
            
            # Web3区块链
            "Web3区块链专家": ExpertType.WEB3_BLOCKCHAIN,
            "Web3 Go开发专家": ExpertType.WEB3_GO,
            "Solana开发专家": ExpertType.SOLANA_DEV,
            "Solidity智能合约架构师": ExpertType.SOLIDITY_CONTRACT,
            
            # 产品和运营
            "高级产品思维专家": ExpertType.PRODUCT_MANAGER,
            "高级运营策略架构师": ExpertType.OPERATION_STRATEGY
        }
        return type_mapping.get(expert_name, ExpertType.JAVA_BACKEND)
    
    def _extract_skills(self, content: str) -> List[str]:
        """从内容中提取技能"""
        skills = []
        # 查找技能相关的段落
        skill_patterns = [
            r"##\s*Skills?\s*\n(.*?)(?=\n##|\n#|$)",
            r"##\s*技能\s*\n(.*?)(?=\n##|\n#|$)",
            r"##\s*专长\s*\n(.*?)(?=\n##|\n#|$)"
        ]
        
        for pattern in skill_patterns:
            matches = re.findall(pattern, content, re.DOTALL | re.IGNORECASE)
            for match in matches:
                # 提取列表项
                skill_items = re.findall(r"[-*]\s*([^\n]+)", match)
                skills.extend(skill_items)
        
        return skills[:10]  # 限制技能数量
    
    def select_experts(self, user_input: str, complexity: int) -> List[ExpertType]:
        """智能选择专家"""
        user_input_lower = user_input.lower()
        scores = {}
        
        for expert_name, expert in self.experts.items():
            score = 0
            
            # 关键词匹配
            for keyword in expert.keywords:
                if keyword.lower() in user_input_lower:
                    score += 10
            
            # 技能匹配
            for skill in expert.skills:
                if any(word in user_input_lower for word in skill.lower().split()):
                    score += 5
            
            if score > 0:
                scores[expert.type] = score
        
        # 根据复杂度选择专家数量
        max_experts = min(complexity // 2 + 1, 3)
        selected = sorted(scores.items(), key=lambda x: x[1], reverse=True)[:max_experts]
        
        # 如果没有匹配的专家，使用默认专家
        if not selected:
            if any(word in user_input_lower for word in ["前端", "react", "vue", "ui"]):
                return [ExpertType.REACT_FRONTEND]
            elif any(word in user_input_lower for word in ["android", "移动", "app"]):
                return [ExpertType.ANDROID_MOBILE]
            elif any(word in user_input_lower for word in ["区块链", "web3", "智能合约"]):
                return [ExpertType.WEB3_BLOCKCHAIN]
            else:
                return [ExpertType.JAVA_BACKEND]
        
        return [expert_type for expert_type, _ in selected]
    
    def get_expert_info(self, expert_name: str) -> Optional[ExpertRule]:
        """获取专家信息"""
        return self.experts.get(expert_name)

class WorkflowController:
    """工作流控制器"""
    
    def __init__(self):
        self.active_workflows: Dict[str, WorkflowState] = {}
    
    def initialize(self, user_input: str) -> WorkflowState:
        """初始化工作流"""
        import uuid
        request_id = str(uuid.uuid4())
        
        # 评估复杂度
        complexity = self._assess_complexity(user_input)
        
        workflow_state = WorkflowState(
            request_id=request_id,
            user_input=user_input,
            complexity=complexity,
            selected_experts=[],
            layer_outputs={}
        )
        
        self.active_workflows[request_id] = workflow_state
        return workflow_state
    
    def _assess_complexity(self, user_input: str) -> int:
        """评估项目复杂度 (1-10)"""
        complexity_indicators = {
            "企业级": 3, "分布式": 2, "微服务": 2, "高并发": 2,
            "大数据": 2, "机器学习": 2, "区块链": 2, "安全": 1,
            "实时": 2, "集群": 2, "缓存": 1, "消息队列": 1,
            "数据库": 1, "api": 1, "web": 1, "移动": 1
        }
        
        score = 3  # 基础复杂度
        user_input_lower = user_input.lower()
        
        for indicator, weight in complexity_indicators.items():
            if indicator in user_input_lower:
                score += weight
        
        return min(score, 10)

class RulesModuleLoader:
    """规则模块加载器"""
    
    def __init__(self):
        self.rules_modules_path = Path(".cursor/rules/rules-modules")
        self.loaded_modules = {}
        self.load_all_modules()
    
    def load_all_modules(self):
        """加载所有规则模块"""
        if not self.rules_modules_path.exists():
            print("⚠️  规则模块目录不存在")
            return
        
        module_files = {
            "product-analyst": "L1产品需求分析模块",
            "tech-architect": "L2技术架构设计模块", 
            "code-implementation": "L3代码实现模块",
            "quality-assurance": "L4质量保证模块",
            "expert-selector": "专家选择器模块",
            "workflow-controller": "工作流控制器模块"
        }
        
        for file_name, description in module_files.items():
            file_path = self.rules_modules_path / f"{file_name}.md"
            if file_path.exists():
                try:
                    with open(file_path, 'r', encoding='utf-8') as f:
                        content = f.read()
                    
                    self.loaded_modules[file_name] = {
                        "description": description,
                        "content": content,
                        "file_path": str(file_path),
                        "rules": self._extract_rules(content),
                        "prompts": self._extract_prompts(content)
                    }
                    print(f"✅ 加载规则模块: {description}")
                except Exception as e:
                    print(f"❌ 加载规则模块失败 {file_path}: {e}")
    
    def _extract_rules(self, content: str) -> Dict:
        """从模块内容中提取规则"""
        rules = {}
        
        # 提取YAML规则块
        yaml_pattern = r"```yaml(.*?)```"
        yaml_matches = re.findall(yaml_pattern, content, re.DOTALL)
        for i, yaml_content in enumerate(yaml_matches):
            rules[f"rule_{i}"] = yaml_content.strip()
        
        # 提取Python规则块
        python_pattern = r"```python(.*?)```" 
        python_matches = re.findall(python_pattern, content, re.DOTALL)
        for i, python_content in enumerate(python_matches):
            rules[f"python_rule_{i}"] = python_content.strip()
        
        return rules
    
    def _extract_prompts(self, content: str) -> List[str]:
        """提取提示词模板"""
        prompts = []
        
        # 查找提示词相关段落
        prompt_patterns = [
            r"提示词模板:(.*?)(?=\n##|\n#|$)",
            r"专家调用:(.*?)(?=\n##|\n#|$)",
            r"处理逻辑:(.*?)(?=\n##|\n#|$)"
        ]
        
        for pattern in prompt_patterns:
            matches = re.findall(pattern, content, re.DOTALL)
            prompts.extend(matches)
        
        return prompts
    
    def get_module(self, module_name: str) -> Optional[Dict]:
        """获取指定模块"""
        return self.loaded_modules.get(module_name)
    
    def get_module_rules(self, module_name: str) -> Dict:
        """获取模块的规则"""
        module = self.get_module(module_name)
        return module.get("rules", {}) if module else {}
    
    def get_module_prompts(self, module_name: str) -> List[str]:
        """获取模块的提示词"""
        module = self.get_module(module_name)
        return module.get("prompts", []) if module else []

class LayerProcessor:
    """层处理器基类"""
    
    def __init__(self, expert_selector: ExpertSelector, rules_loader: RulesModuleLoader):
        self.expert_selector = expert_selector
        self.rules_loader = rules_loader
    
    def process(self, input_data: Any, workflow_state: WorkflowState) -> Dict:
        """处理层逻辑"""
        raise NotImplementedError
    
    def call_expert_with_rules(self, expert_type: str, prompt: str, rules_context: Dict) -> str:
        """使用规则调用专家"""
        # 获取专家信息
        expert_info = self.expert_selector.get_expert_info(expert_type)
        
        if not expert_info:
            return f"未找到专家: {expert_type}"
        
        # 构建完整的提示词
        full_prompt = f"""
{expert_info.rules_content[:1000]}...

当前任务规则:
{json.dumps(rules_context, ensure_ascii=False, indent=2)}

用户请求: {prompt}

请按照上述专家规则和任务规则进行处理，输出结构化结果。
"""
        
        # 这里可以集成LLM调用，目前返回模拟结果
        return f"基于{expert_info.name}的专业处理结果"

class L1ProductAnalyst(LayerProcessor):
    """L1: 产品需求分析层"""
    
    def process(self, input_data: str, workflow_state: WorkflowState) -> Dict:
        """产品需求分析 - 使用规则模块"""
        print("🎯 执行L1产品需求分析层...")
        
        # 加载L1层规则模块
        l1_rules = self.rules_loader.get_module_rules("product-analyst")
        l1_prompts = self.rules_loader.get_module_prompts("product-analyst")
        
        # 选择产品专家
        product_expert = None
        for expert_name, expert in self.expert_selector.experts.items():
            if "产品" in expert_name:
                product_expert = expert
                break
        
        if not product_expert:
            print("⚠️  未找到产品专家，使用默认分析")
            
        # 使用规则模块进行分析
        analysis_prompt = f"""
作为产品需求分析专家，请按照IACC 2.0的L1层规则对以下需求进行分析：

用户需求: {input_data}
项目复杂度: {workflow_state.complexity}
选定专家: {[expert.value for expert in workflow_state.selected_experts]}

请按照以下结构进行分析：
1. 需求理解和意图识别
2. 用户场景和旅程分析  
3. 功能模块抽象
4. 技术方向评估
5. 复杂度评估

输出标准的L1层结果格式。
"""
        
        # 调用专家进行分析
        if product_expert:
            expert_result = self.call_expert_with_rules(
                product_expert.name, 
                analysis_prompt,
                {"layer": "L1", "rules": l1_rules}
            )
        
        # 构建标准化输出
        analysis = {
            "layer": "L1",
            "description": "产品需求分析层",
            "需求理解": {
                "原始需求": input_data,
                "项目类型": self._identify_project_type(input_data),
                "业务领域": self._identify_business_domain(input_data),
                "核心目标": self._extract_business_goals(input_data)
            },
            "用户场景分析": self._analyze_user_scenarios_with_rules(input_data, l1_rules),
            "功能模块清单": self._extract_features_with_rules(input_data, l1_rules),
            "技术方向建议": self._suggest_tech_direction_with_rules(input_data, workflow_state),
            "复杂度评估": {
                "技术复杂度": workflow_state.complexity,
                "业务复杂度": self._assess_business_complexity(input_data),
                "总体评分": workflow_state.complexity,
                "开发周期预估": self._estimate_development_time(workflow_state.complexity)
            },
            "推荐专家组合": [expert.value for expert in workflow_state.selected_experts],
            "规则应用状态": f"应用了{len(l1_rules)}条L1层规则" if l1_rules else "使用默认规则"
        }
        
        if product_expert:
            analysis["专家分析"] = f"基于{product_expert.name}的专业分析"
        
        return analysis
    
    def _identify_project_type(self, input_data: str) -> str:
        """识别项目类型"""
        input_lower = input_data.lower()
        if any(word in input_lower for word in ["app", "android", "移动"]):
            return "移动应用"
        elif any(word in input_lower for word in ["前端", "react", "vue", "ui"]):
            return "前端应用"  
        elif any(word in input_lower for word in ["区块链", "web3", "智能合约", "defi"]):
            return "区块链项目"
        elif any(word in input_lower for word in ["后端", "api", "服务", "系统"]):
            return "后端系统"
        else:
            return "全栈应用"
    
    def _identify_business_domain(self, input_data: str) -> str:
        """识别业务领域"""
        input_lower = input_data.lower()
        if any(word in input_lower for word in ["电商", "购物", "商城"]):
            return "电商"
        elif any(word in input_lower for word in ["金融", "支付", "交易"]):
            return "金融"
        elif any(word in input_lower for word in ["教育", "学习", "课程"]):
            return "教育"
        elif any(word in input_lower for word in ["管理", "crm", "erp", "企业"]):
            return "企业服务"
        else:
            return "通用应用"
    
    def _extract_business_goals(self, input_data: str) -> List[str]:
        """提取业务目标"""
        goals = []
        input_lower = input_data.lower()
        
        goal_mapping = {
            "提高效率": ["管理", "自动化", "流程"],
            "降低成本": ["优化", "节省", "减少"],
            "增加收入": ["销售", "营收", "盈利"],
            "改善体验": ["用户", "体验", "界面", "交互"]
        }
        
        for goal, keywords in goal_mapping.items():
            if any(keyword in input_lower for keyword in keywords):
                goals.append(goal)
        
        return goals or ["业务功能实现"]
    
    def _analyze_user_scenarios_with_rules(self, input_data: str, rules: Dict) -> List[str]:
        """基于规则分析用户场景"""
        scenarios = []
        input_lower = input_data.lower()
        
        # 基础场景识别
        if "登录" in input_lower or "用户" in input_lower:
            scenarios.append("用户注册登录场景")
        if "管理" in input_lower:
            scenarios.append("管理员操作场景")
        if "查询" in input_lower or "搜索" in input_lower:
            scenarios.append("信息查询场景")
        if "支付" in input_lower or "订单" in input_lower:
            scenarios.append("交易支付场景")
        
        return scenarios or ["基础功能使用场景"]
    
    def _extract_features_with_rules(self, input_data: str, rules: Dict) -> List[str]:
        """基于规则提取功能清单"""
        features = []
        input_lower = input_data.lower()
        
        feature_mapping = {
            "用户管理模块": ["用户", "登录", "注册", "权限"],
            "数据管理模块": ["数据", "查询", "统计", "报表"],
            "业务处理模块": ["订单", "流程", "审批", "处理"],
            "系统管理模块": ["配置", "监控", "日志", "系统"],
            "接口服务模块": ["api", "接口", "集成", "对接"]
        }
        
        for feature, keywords in feature_mapping.items():
            if any(keyword in input_lower for keyword in keywords):
                features.append(feature)
        
        return features or ["基础CRUD功能模块"]
    
    def _suggest_tech_direction_with_rules(self, input_data: str, workflow_state: WorkflowState) -> Dict:
        """基于规则建议技术方向"""
        experts = workflow_state.selected_experts
        
        direction = {
            "推荐架构": "分层架构",
            "技术栈": [],
            "架构模式": "单体应用"
        }
        
        for expert in experts:
            if expert == ExpertType.JAVA_BACKEND:
                direction["技术栈"].extend(["Spring Boot", "MySQL", "Redis"])
                direction["架构模式"] = "微服务架构"
            elif expert == ExpertType.REACT_FRONTEND:
                direction["技术栈"].extend(["React", "TypeScript", "Ant Design"])
            elif expert == ExpertType.ANDROID_MOBILE:
                direction["技术栈"].extend(["Android", "Kotlin", "Jetpack"])
            elif expert in [ExpertType.WEB3_BLOCKCHAIN, ExpertType.SOLIDITY_CONTRACT]:
                direction["技术栈"].extend(["Solidity", "Web3.js", "Hardhat"])
                direction["架构模式"] = "区块链DApp架构"
        
        return direction
    
    def _assess_business_complexity(self, input_data: str) -> int:
        """评估业务复杂度"""
        complexity = 3
        input_lower = input_data.lower()
        
        complexity_indicators = {
            "workflow": 2, "流程": 2, "审批": 2,
            "权限": 1, "角色": 1, "多租户": 3,
            "分布式": 3, "集群": 2, "高可用": 2
        }
        
        for indicator, weight in complexity_indicators.items():
            if indicator in input_lower:
                complexity += weight
        
        return min(complexity, 10)
    
    def _estimate_development_time(self, complexity: int) -> str:
        """估算开发时间"""
        if complexity <= 3:
            return "2-4周"
        elif complexity <= 6:
            return "1-3个月"
        elif complexity <= 8:
            return "3-6个月"
        else:
            return "6个月以上"
    
    def _parse_requirements(self, input_data: str) -> str:
        """解析需求"""
        return f"核心需求: {input_data[:100]}..."
    
    def _analyze_user_scenarios(self, input_data: str) -> List[str]:
        """分析用户场景"""
        scenarios = []
        if "管理" in input_data:
            scenarios.append("管理员管理场景")
        if "用户" in input_data:
            scenarios.append("普通用户使用场景")
        if "系统" in input_data:
            scenarios.append("系统自动化场景")
        return scenarios or ["基础功能使用场景"]
    
    def _extract_features(self, input_data: str) -> List[str]:
        """提取功能清单"""
        features = []
        feature_keywords = {
            "登录": "用户认证系统",
            "管理": "管理后台",
            "支付": "支付系统", 
            "聊天": "即时通讯",
            "搜索": "搜索功能",
            "推荐": "推荐系统"
        }
        
        for keyword, feature in feature_keywords.items():
            if keyword in input_data:
                features.append(feature)
        
        return features or ["基础CRUD功能"]
    
    def _suggest_tech_direction(self, input_data: str) -> str:
        """建议技术方向"""
        if any(word in input_data for word in ["web", "网站", "前端"]):
            return "Web前端 + 后端API架构"
        elif "app" in input_data or "移动" in input_data:
            return "移动端原生开发"
        elif "区块链" in input_data or "智能合约" in input_data:
            return "区块链DApp开发"
        else:
            return "后端服务 + Web前端"

class L2TechArchitect(LayerProcessor):
    """L2: 技术架构设计层"""
    
    def process(self, input_data: Dict, workflow_state: WorkflowState) -> Dict:
        """技术架构设计"""
        tech_direction = input_data.get("技术方向", "")
        
        architecture = {
            "系统架构": self._design_architecture(tech_direction, workflow_state),
            "技术选型": self._select_tech_stack(workflow_state.selected_experts),
            "数据设计": self._design_database(input_data),
            "接口定义": self._define_apis(input_data),
            "部署架构": self._design_deployment(workflow_state.complexity)
        }
        
        return architecture
    
    def _design_architecture(self, tech_direction: str, workflow_state: WorkflowState) -> Dict:
        """设计系统架构"""
        if ExpertType.WEB3_BLOCKCHAIN in workflow_state.selected_experts:
            return {
                "架构模式": "区块链DApp三层架构",
                "前端层": "React + Web3.js",
                "智能合约层": "Solidity合约",
                "存储层": "IPFS + 链上存储"
            }
        elif ExpertType.ANDROID_MOBILE in workflow_state.selected_experts:
            return {
                "架构模式": "MVVM架构模式",
                "表现层": "Activity/Fragment + DataBinding",
                "业务层": "ViewModel + Repository",
                "数据层": "Room + Retrofit"
            }
        else:
            return {
                "架构模式": "分层架构 + 微服务",
                "表现层": "React/Vue SPA",
                "业务层": "Spring Boot微服务",
                "数据层": "MySQL + Redis"
            }
    
    def _select_tech_stack(self, selected_experts: List[ExpertType]) -> Dict:
        """选择技术栈"""
        tech_stack = {"后端": [], "前端": [], "数据库": [], "工具": []}
        
        for expert in selected_experts:
            if expert == ExpertType.JAVA_BACKEND:
                tech_stack["后端"] = ["Spring Boot", "Spring Cloud", "MyBatis"]
                tech_stack["数据库"] = ["MySQL", "Redis", "MongoDB"]
            elif expert == ExpertType.REACT_FRONTEND:
                tech_stack["前端"] = ["React 18", "TypeScript", "Ant Design"]
            elif expert == ExpertType.VUE_FRONTEND:
                tech_stack["前端"] = ["Vue 3", "TypeScript", "Element Plus"]
            elif expert == ExpertType.ANDROID_MOBILE:
                tech_stack["移动端"] = ["Kotlin", "Jetpack Compose", "Room"]
            elif expert == ExpertType.WEB3_BLOCKCHAIN:
                tech_stack["区块链"] = ["Solidity", "Hardhat", "OpenZeppelin"]
        
        tech_stack["工具"] = ["Docker", "K8s", "Jenkins", "Git"]
        return tech_stack
    
    def _design_database(self, input_data: Dict) -> Dict:
        """设计数据库"""
        features = input_data.get("功能清单", [])
        
        tables = []
        if any("用户" in feature for feature in features):
            tables.append("users - 用户基础信息表")
        if any("管理" in feature for feature in features):
            tables.append("admin_users - 管理员用户表")
        
        return {
            "数据库类型": "MySQL 8.0",
            "核心表设计": tables,
            "缓存策略": "Redis分布式缓存",
            "数据分片": "按用户ID分片" if len(tables) > 3 else "单库架构"
        }
    
    def _define_apis(self, input_data: Dict) -> List[str]:
        """定义API接口"""
        features = input_data.get("功能清单", [])
        apis = []
        
        for feature in features:
            if "认证" in feature:
                apis.extend([
                    "POST /api/auth/login - 用户登录",
                    "POST /api/auth/logout - 用户登出"
                ])
            elif "管理" in feature:
                apis.extend([
                    "GET /api/admin/users - 获取用户列表",
                    "POST /api/admin/users - 创建用户"
                ])
        
        return apis or ["GET /api/health - 健康检查"]
    
    def _design_deployment(self, complexity: int) -> Dict:
        """设计部署架构"""
        if complexity >= 7:
            return {
                "部署方式": "Kubernetes集群",
                "服务治理": "Istio服务网格",
                "监控体系": "Prometheus + Grafana",
                "日志系统": "ELK Stack"
            }
        else:
            return {
                "部署方式": "Docker容器",
                "负载均衡": "Nginx",
                "监控体系": "基础监控",
                "日志系统": "文件日志"
            }

class L3CodeImplementation(LayerProcessor):
    """L3: 代码实现层"""
    
    def process(self, input_data: Dict, workflow_state: WorkflowState) -> Dict:
        """代码实现"""
        tech_stack = input_data.get("技术选型", {})
        
        implementation = {
            "项目结构": self._generate_project_structure(workflow_state.selected_experts),
            "核心代码": self._generate_core_code(tech_stack, workflow_state.selected_experts),
            "单元测试": self._generate_unit_tests(workflow_state.selected_experts),
            "配置文件": self._generate_configs(tech_stack),
            "构建脚本": self._generate_build_scripts(workflow_state.selected_experts)
        }
        
        return implementation
    
    def _generate_project_structure(self, selected_experts: List[ExpertType]) -> Dict:
        """生成项目结构"""
        if ExpertType.JAVA_BACKEND in selected_experts:
            return {
                "项目类型": "Spring Boot项目",
                "目录结构": {
                    "src/main/java": "Java源码",
                    "src/main/resources": "配置文件",
                    "src/test/java": "测试代码",
                    "pom.xml": "Maven配置"
                }
            }
        elif ExpertType.REACT_FRONTEND in selected_experts:
            return {
                "项目类型": "React项目",
                "目录结构": {
                    "src/components": "React组件",
                    "src/pages": "页面组件",
                    "src/utils": "工具函数",
                    "package.json": "依赖配置"
                }
            }
        elif ExpertType.ANDROID_MOBILE in selected_experts:
            return {
                "项目类型": "Android项目",
                "目录结构": {
                    "app/src/main/java": "Kotlin源码",
                    "app/src/main/res": "资源文件",
                    "app/build.gradle": "构建配置",
                    "AndroidManifest.xml": "应用清单"
                }
            }
        else:
            return {"项目类型": "通用项目", "目录结构": {"src": "源码目录"}}
    
    def _generate_core_code(self, tech_stack: Dict, selected_experts: List[ExpertType]) -> Dict:
        """生成核心代码"""
        code_samples = {}
        
        if ExpertType.JAVA_BACKEND in selected_experts:
            code_samples["Application.java"] = """
@SpringBootApplication
public class Application {
    public static void main(String[] args) {
        SpringApplication.run(Application.class, args);
    }
}
"""
            code_samples["UserController.java"] = """
@RestController
@RequestMapping("/api/users")
public class UserController {
    
    @Autowired
    private UserService userService;
    
    @GetMapping
    public ResponseEntity<List<User>> getUsers() {
        return ResponseEntity.ok(userService.findAll());
    }
}
"""
        
        if ExpertType.REACT_FRONTEND in selected_experts:
            code_samples["App.tsx"] = """
import React from 'react';
import { BrowserRouter as Router, Routes, Route } from 'react-router-dom';

function App() {
  return (
    <Router>
      <Routes>
        <Route path="/" element={<Home />} />
      </Routes>
    </Router>
  );
}

export default App;
"""
        
        return code_samples
    
    def _generate_unit_tests(self, selected_experts: List[ExpertType]) -> Dict:
        """生成单元测试"""
        tests = {}
        
        if ExpertType.JAVA_BACKEND in selected_experts:
            tests["UserControllerTest.java"] = """
@SpringBootTest
@AutoConfigureTestDatabase
class UserControllerTest {
    
    @Autowired
    private TestRestTemplate restTemplate;
    
    @Test
    void testGetUsers() {
        ResponseEntity<String> response = 
            restTemplate.getForEntity("/api/users", String.class);
        assertEquals(HttpStatus.OK, response.getStatusCode());
    }
}
"""
        
        return tests
    
    def _generate_configs(self, tech_stack: Dict) -> Dict:
        """生成配置文件"""
        configs = {}
        
        if "Spring Boot" in str(tech_stack):
            configs["application.yml"] = """
server:
  port: 8080
spring:
  datasource:
    url: jdbc:mysql://localhost:3306/demo
    username: root
    password: password
  jpa:
    hibernate:
      ddl-auto: update
"""
        
        configs["Dockerfile"] = """
FROM openjdk:17-jre-slim
COPY target/*.jar app.jar
EXPOSE 8080
ENTRYPOINT ["java", "-jar", "/app.jar"]
"""
        
        return configs
    
    def _generate_build_scripts(self, selected_experts: List[ExpertType]) -> Dict:
        """生成构建脚本"""
        scripts = {}
        
        if ExpertType.JAVA_BACKEND in selected_experts:
            scripts["build.sh"] = """
#!/bin/bash
mvn clean package
docker build -t myapp:latest .
"""
        
        scripts["deploy.yml"] = """
apiVersion: apps/v1
kind: Deployment
metadata:
  name: myapp
spec:
  replicas: 3
  selector:
    matchLabels:
      app: myapp
  template:
    metadata:
      labels:
        app: myapp
    spec:
      containers:
      - name: myapp
        image: myapp:latest
        ports:
        - containerPort: 8080
"""
        
        return scripts

class L4QualityAssurance(LayerProcessor):
    """L4: 质量保证层"""
    
    def process(self, input_data: Dict, workflow_state: WorkflowState) -> Dict:
        """质量保证检查"""
        quality_report = {
            "架构审查": self._review_architecture(input_data),
            "代码质量": self._analyze_code_quality(input_data),
            "性能测试": self._performance_analysis(workflow_state.complexity),
            "安全检查": self._security_audit(input_data),
            "部署就绪": self._deployment_readiness(input_data),
            "质量评分": self._calculate_quality_score(input_data)
        }
        
        return quality_report
    
    def _review_architecture(self, input_data: Dict) -> Dict:
        """架构审查"""
        return {
            "分层架构": "✅ 严格遵循分层架构原则",
            "设计模式": "✅ 正确应用设计模式",
            "SOLID原则": "✅ 符合SOLID设计原则",
            "依赖注入": "✅ 合理使用依赖注入"
        }
    
    def _analyze_code_quality(self, input_data: Dict) -> Dict:
        """代码质量分析"""
        core_code = input_data.get("核心代码", {})
        
        return {
            "代码规范": "✅ 遵循编码规范",
            "测试覆盖": f"✅ 单元测试覆盖率: {len(core_code) * 15}%",
            "代码复杂度": "✅ 代码复杂度可控",
            "文档完整性": "✅ 代码注释完整"
        }
    
    def _performance_analysis(self, complexity: int) -> Dict:
        """性能分析"""
        expected_qps = max(1000, complexity * 100)
        
        return {
            "响应时间": "< 200ms (P95)",
            "吞吐量": f"> {expected_qps} QPS",
            "内存使用": "< 512MB (正常负载)",
            "CPU使用率": "< 60% (峰值负载)"
        }
    
    def _security_audit(self, input_data: Dict) -> Dict:
        """安全审计"""
        return {
            "输入验证": "✅ 参数校验完整",
            "权限控制": "✅ 基于角色的权限控制",
            "数据加密": "✅ 敏感数据加密存储",
            "SQL注入": "✅ 使用参数化查询"
        }
    
    def _deployment_readiness(self, input_data: Dict) -> Dict:
        """部署就绪检查"""
        configs = input_data.get("配置文件", {})
        
        return {
            "Docker化": "✅ 支持容器化部署" if "Dockerfile" in configs else "❌ 缺少Docker配置",
            "K8s支持": "✅ 支持K8s部署" if "deploy.yml" in configs else "⚠️  建议添加K8s配置",
            "健康检查": "✅ 配置健康检查端点",
            "日志规范": "✅ 结构化日志输出"
        }
    
    def _calculate_quality_score(self, input_data: Dict) -> int:
        """计算质量评分"""
        base_score = 85
        
        # 根据代码完整性加分
        if len(input_data.get("核心代码", {})) >= 3:
            base_score += 5
        
        # 根据测试完整性加分
        if len(input_data.get("单元测试", {})) >= 1:
            base_score += 5
        
        # 根据配置完整性加分
        if len(input_data.get("配置文件", {})) >= 2:
            base_score += 5
        
        return min(base_score, 100)

class IACC2Controller:
    """IACC 2.0 主控制器"""
    
    def __init__(self):
        print("🚀 初始化IACC 2.0智能代理协作控制器...")
        
        # 初始化核心组件
        self.rules_loader = RulesModuleLoader()
        self.workflow_controller = WorkflowController()
        self.expert_selector = ExpertSelector()
        
        # 初始化4层处理器（传入规则加载器）
        self.layers = {
            LayerType.L1_PRODUCT: L1ProductAnalyst(self.expert_selector, self.rules_loader),
            LayerType.L2_ARCHITECT: L2TechArchitect(self.expert_selector, self.rules_loader),
            LayerType.L3_IMPLEMENTATION: L3CodeImplementation(self.expert_selector, self.rules_loader),
            LayerType.L4_QUALITY: L4QualityAssurance(self.expert_selector, self.rules_loader)
        }
        
        print(f"✅ 系统初始化完成")
        print(f"📊 已加载 {len(self.rules_loader.loaded_modules)} 个规则模块")
        print(f"🧠 已加载 {len(self.expert_selector.experts)} 个专家")
    
    def process_request(self, user_input: str, mode: str = "standard") -> Dict:
        """4层精简工作流处理"""
        try:
            # 工作流初始化
            workflow_state = self.workflow_controller.initialize(user_input)
            
            # 智能选择专家
            workflow_state.selected_experts = self.expert_selector.select_experts(
                user_input, workflow_state.complexity
            )
            
            # 执行4层流程
            l1_output = self.execute_layer(LayerType.L1_PRODUCT, user_input, workflow_state)
            l2_output = self.execute_layer(LayerType.L2_ARCHITECT, l1_output, workflow_state)
            l3_output = self.execute_layer(LayerType.L3_IMPLEMENTATION, l2_output, workflow_state)
            
            # 根据模式决定是否执行质量检查
            if mode in ["standard", "quality"]:
                l4_output = self.execute_layer(LayerType.L4_QUALITY, l3_output, workflow_state)
                final_output = l4_output
            else:
                final_output = l3_output
            
            return self.package_delivery(workflow_state, final_output)
            
        except Exception as e:
            return {
                "error": f"处理请求失败: {str(e)}",
                "status": "failed"
            }
    
    def execute_layer(self, layer_type: LayerType, input_data: Any, workflow_state: WorkflowState) -> Dict:
        """执行指定层的处理"""
        workflow_state.current_layer = layer_type
        
        layer_processor = self.layers[layer_type]
        output = layer_processor.process(input_data, workflow_state)
        
        workflow_state.layer_outputs[layer_type] = output
        return output
    
    def package_delivery(self, workflow_state: WorkflowState, final_output: Dict) -> Dict:
        """打包交付结果"""
        return {
            "request_id": workflow_state.request_id,
            "user_input": workflow_state.user_input,
            "complexity": workflow_state.complexity,
            "selected_experts": [expert.value for expert in workflow_state.selected_experts],
            "layer_outputs": {
                layer.value: output 
                for layer, output in workflow_state.layer_outputs.items()
            },
            "final_delivery": final_output,
            "status": "completed",
            "quality_score": final_output.get("质量评分", 90) if "质量评分" in final_output else 90
        }

# 创建全局控制器实例
iacc_controller = IACC2Controller()

# MCP工具定义
@mcp.tool()
def iacc_process(user_input: str, mode: str = "standard") -> str:
    """
    IACC 2.0 智能代理协作控制器 - 4层精简架构处理
    
    Args:
        user_input: 用户需求输入
        mode: 处理模式 (standard/fast/quality)
            - standard: 标准4层流程
            - fast: 快速模式(跳过质量检查)
            - quality: 质量模式(强化质量保证)
    
    Returns:
        完整的处理结果，包含4层输出和最终交付包
    """
    try:
        result = iacc_controller.process_request(user_input, mode)
        return json.dumps(result, ensure_ascii=False, indent=2)
    except Exception as e:
        return f"处理失败: {str(e)}"

@mcp.tool()
def list_available_experts() -> str:
    """获取可用的专家列表"""
    experts_info = []
    for expert_name, expert_rule in iacc_controller.expert_selector.experts.items():
        experts_info.append({
            "name": expert_name,
            "type": expert_rule.type.value,
            "keywords": expert_rule.keywords,
            "skills_count": len(expert_rule.skills),
            "file_path": expert_rule.file_path
        })
    
    return json.dumps({
        "total_experts": len(experts_info),
        "experts": experts_info
    }, ensure_ascii=False, indent=2)

@mcp.tool()
def analyze_complexity(user_input: str) -> str:
    """分析项目复杂度和推荐专家"""
    workflow_state = iacc_controller.workflow_controller.initialize(user_input)
    selected_experts = iacc_controller.expert_selector.select_experts(
        user_input, workflow_state.complexity
    )
    
    result = {
        "user_input": user_input,
        "complexity_score": workflow_state.complexity,
        "complexity_level": "简单" if workflow_state.complexity <= 3 
                           else "中等" if workflow_state.complexity <= 6 
                           else "复杂",
        "recommended_experts": [expert.value for expert in selected_experts],
        "estimated_layers": 4 if workflow_state.complexity >= 4 else 3
    }
    
    return json.dumps(result, ensure_ascii=False, indent=2)

# 添加资源
@mcp.resource("iacc://system/status")
def get_system_status() -> str:
    """获取IACC系统状态"""
    return json.dumps({
        "system": "IACC 2.0",
        "version": "2.0.1",
        "architecture": "4层精简架构",
        "active_workflows": len(iacc_controller.workflow_controller.active_workflows),
        "available_experts": len(iacc_controller.expert_selector.experts),
        "layers": [layer.value for layer in LayerType],
        "status": "operational"
    }, ensure_ascii=False, indent=2)

@mcp.resource("iacc://expert/{expert_type}")
def get_expert_details(expert_type: str) -> str:
    """获取专家详细信息"""
    for expert_name, expert_rule in iacc_controller.expert_selector.experts.items():
        if expert_rule.type.value == expert_type or expert_name == expert_type:
            return json.dumps({
                "name": expert_name,
                "type": expert_rule.type.value,
                "keywords": expert_rule.keywords,
                "skills": expert_rule.skills,
                "file_path": expert_rule.file_path,
                "rules_preview": expert_rule.rules_content[:500] + "..." if len(expert_rule.rules_content) > 500 else expert_rule.rules_content
            }, ensure_ascii=False, indent=2)
    
    return json.dumps({"error": "专家未找到"}, ensure_ascii=False)

def main() -> None:
    """启动MCP服务器"""
    mcp.run(transport="stdio")

if __name__ == "__main__":
    main()

